exportPattern("^[[:alpha:]]+")
importFrom(e1071, cmeans)
importFrom(mclust, Mclust)
importFrom(mclust, mclustBIC)
importFrom(graphics, par)
importFrom(graphics, points)
import("stats")
import("mclust")
import("e1071")
