#' @title D9 Artificial Dataset
#' @description A \code{2}-dimensional dataset from Wiroonsri and Preedasawakul (2023) generated from \code{3} different Uniform distributions labeled as \code{1-3}.
#' @format A data frame with 1000 data points and 3 variables
#' \describe{
#'   \item{\code{x}}{Numeric values generated from Uniform distributions}
#'   \item{\code{y}}{Numeric values generated from Uniform distributions}
#'   \item{\code{label}}{Categorical labels 1,2,3}
#'}
#' @references  {N. Wiroonsri, O. Preedasawakul, A correlation-based fuzzy cluster validity index with secondary options detector, arXiv:2308.14785, 2023}
#' @author {Nathakhun Wiroonsri and Onthada Preedasawakul}
#' @seealso {\link{FzzyCVIs},  \link{WP.IDX},  \link{D1_data}, \link{Hvalid}, \link{DI.IDX}}
"D9_data"
